@@ -1,11 +1,5 @@
 import os 
 import requests
-import eon_logger.logging as log
-
-
-cls = log.Logger('fms', 'info')
-_logger = cls.create_logger()
-
 
 class FilesManager():
     def __init__(self, config):
